@@ -4,8 +4,8 @@
  * SPDX-License-Identifier: Apache-2.0.
  */
 
-#define AWS_CRT_CPP_VERSION "0.26.2-dev+25f833ea"
+#define AWS_CRT_CPP_VERSION "0.28.2"
 #define AWS_CRT_CPP_VERSION_MAJOR 0
-#define AWS_CRT_CPP_VERSION_MINOR 26
+#define AWS_CRT_CPP_VERSION_MINOR 28
 #define AWS_CRT_CPP_VERSION_PATCH 2
-#define AWS_CRT_CPP_GIT_HASH "25f833ea570d343acbdd2be9e7012abc379082fa"
+#define AWS_CRT_CPP_GIT_HASH ""
